@@ -4,7 +4,7 @@
 * License: GPL
 * Copyright (c) 1999-2007 nagios-plugins team
 *
-* Last Modified: $Date: 2007/06/03 14:40:10 $
+* Last Modified: $Date: 2007-09-22 18:48:33 +0100 (Sat, 22 Sep 2007) $
 *
 * Description:
 *
@@ -26,7 +26,7 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: utils_tcp.c,v 1.1 2007/06/03 14:40:10 psychotrahe Exp $
+* $Id: utils_tcp.c 1787 2007-09-22 17:48:33Z psychotrahe $
 *
 *****************************************************************************/
 
@@ -52,9 +52,9 @@ np_expect_match(char* status, char** server_expect, int expect_count, int all, i
 		} else
 			if(verbose) puts("couldn't find it");
 	}
-	if ((all == true && match == expect_count) ||
+	if ((all == TRUE && match == expect_count) ||
 		(! all && match >= 1)) {
-		return true;
+		return TRUE;
 	} else
-		return false;
+		return FALSE;
 }
