@@ -5,7 +5,7 @@
 * License: GPL
 * Copyright (c) 1999-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2007/04/18 19:31:29 $
+* Last Modified: $Date: 2007-09-23 13:26:03 +0100 (Sun, 23 Sep 2007) $
 *
 * Description:
 *
@@ -27,12 +27,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_by_ssh.c,v 1.43 2007/04/18 19:31:29 hweiss Exp $
+* $Id: check_by_ssh.c 1792 2007-09-23 12:26:03Z psychotrahe $
 * 
 ******************************************************************************/
  
 const char *progname = "check_by_ssh";
-const char *revision = "$Revision: 1.43 $";
+const char *revision = "$Revision: 1792 $";
 const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -110,7 +110,8 @@ main (int argc, char **argv)
 	 * Wrap up quickly and keep the tricks below */
 	if(!passive) {
 		if (chld_out.lines > skip_stdout)
-			puts (chld_out.line[skip_stdout]);
+			for (i = skip_stdout; i < chld_out.lines; i++)
+				puts (chld_out.line[i]);
 		else
 			printf (_("%s - check_by_ssh: Remote command '%s' returned status %d\n"),
 			        state_text(result), remotecmd, result);
@@ -399,6 +400,7 @@ print_help (void)
   printf (" %s\n", "[1080933700] PROCESS_SERVICE_CHECK_RESULT;flint;c1;0; up 2 days");
   printf (" %s\n", "[1080933700] PROCESS_SERVICE_CHECK_RESULT;flint;c2;0; up 2 days");
   printf (" %s\n", "[1080933700] PROCESS_SERVICE_CHECK_RESULT;flint;c3;0; up 2 days");
+	printf (_(UT_VERBOSE));
 	printf (_(UT_SUPPORT));
 }
 
@@ -408,7 +410,7 @@ void
 print_usage (void)
 {
 	printf (_("Usage:"));
-	printf (" %s -H <host> -C <command> [-fq] [-1|-2] [-4|-6]\n"
+	printf (" %s -H <host> -C <command> [-fqv] [-1|-2] [-4|-6]\n"
 	        "       [-S [lines]] [-E [lines]] [-t timeout] [-i identity]\n"
 	        "       [-l user] [-n name] [-s servicelist] [-O outputfile]\n"
 	        "       [-p port] [-o ssh-option]\n",
