@@ -6,7 +6,7 @@
 * Copyright (c) 2000 Karl DeBisschop (kdebisschop@users.sourceforge.net)
 * Copyright (c) 2000-2006 nagios-plugins team
 *
-* Last Modified: $Date: 2007-02-07 14:06:11 +0000 (Wed, 07 Feb 2007) $
+* Last Modified: $Date: 2007-12-10 07:52:00 +0000 (Mon, 10 Dec 2007) $
 *
 * Description:
 *
@@ -28,12 +28,12 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
-* $Id: check_swap.c 1613 2007-02-07 14:06:11Z hweiss $
+* $Id: check_swap.c 1859 2007-12-10 07:52:00Z dermoth $
 *
 *****************************************************************************/
 
 const char *progname = "check_swap";
-const char *revision = "$Revision: 1613 $";
+const char *revision = "$Revision: 1859 $";
 const char *copyright = "2000-2006";
 const char *email = "nagiosplug-devel@lists.sourceforge.net";
 
@@ -543,8 +543,7 @@ print_help (void)
   printf ("    %s\n", _("Exit with CRITCAL status if less than PERCENT of swap space is free"));
   printf (" %s\n", "-a, --allswaps");
   printf ("    %s\n", _("Conduct comparisons for all swap partitions, one by one"));
-  printf (" %s\n", "-v, --verbose");
-  printf ("    %s\n", _("Verbose output. Up to 3 levels"));
+	printf (_(UT_VERBOSE));
 	printf ("\n");
   printf ("%s\n", _("Notes:"));
   printf (" %s\n", _("On AIX, if -a is specified, uses lsps -a, otherwise uses lsps -s.\n"));
